@@ -1,3 +1,4 @@
+import logging
 from typing import Optional, List, Union
 from uuid import UUID, uuid4
 
@@ -82,9 +83,13 @@ class Player:
         self.names = []
         for i in range(0, len(names)):
             if isinstance(names[i], str):
-                self.names.append(Name(names[i], None))
+                if not any(n == names[i] for n in self.names):
+                    self.names.append(Name(names[i], None))
             elif isinstance(names[i], Name):
-                self.names.append(names[i])
+                if not any(n == names[i].value for n in self.names):
+                    self.names.append(names[i])
+            else:
+                logging.error(f"player: Can't handle {names[i]} -- expected Name or str. Ignoring.")
 
         if not teams:
             self.teams = []
